@@ -106,20 +106,6 @@ class RestAPI(object):
 			self.firebase = Firebase(firebase_credentials)
 
 		#
-	def generate_key(self):
-		for attempt in range(101):
-			key = Formats.String("").generate(length=68, capitalize=True, digits=True)
-			if key not in self.__plans__["developer"]["api_keys"]:
-				new = True
-				for plan, info in self.__plans__.items():
-					if key in info["api_keys"]: 
-						new = False 
-						break
-				if new:
-					return r3sponse.success_response("Successfully generated a new unique api key.", {
-						"api_key":key
-					})
-		return r3sponse.error_response("Failed to generate a new unique api key.")
 	def identify_key(self, api_key=None):
 
 		# check developer success.
@@ -427,7 +413,7 @@ class RestAPI(object):
 		data = ast.literal_eval(str(self.__default_user_data__))
 
 		# generate api key.
-		response = self.generate_key()
+		response = self.__generate_key__()
 		if response["error"] != None: return response
 		data["api_key"] = response["api_key"]
 
@@ -450,7 +436,7 @@ class RestAPI(object):
 		# test api key.
 		try: data["api_key"]
 		except KeyError: 
-			response = self.generate_key()
+			response = self.__generate_key__()
 			if response["error"] != None: return response
 			data["api_key"] = response["api_key"]
 			edits += 1
@@ -492,4 +478,20 @@ class RestAPI(object):
 					"plan":key,
 				})
 		return r3sponse.error_response(f"Failed to rerieve the plan name for stripe plan id [{plan_id}].")
+	def __generate_key__(self):
+		for attempt in range(101):
+			key = Formats.String("").generate(length=68, capitalize=True, digits=True)
+			if key not in self.__plans__["developer"]["api_keys"]:
+				new = True
+				for plan, info in self.__plans__.items():
+					if key in info["api_keys"]: 
+						new = False 
+						break
+				if new:
+					return r3sponse.success_response("Successfully generated a new unique api key.", {
+						"api_key":key
+					})
+		return r3sponse.error_response("Failed to generate a new unique api key.")
+
+
 
